==> react-7.4.1.tgz: package/es/ListItemHeader/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _inheritsLoose(subClass, superClass) { subClass.prototype.__proto__ = superClass && superClass.prototype; subClass.__proto__ = superClass; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

import React from 'react';
import PropTypes from 'prop-types';
import { ListItem, ListItemSection } from "./..";
import _ from 'lodash';
/**
 * @category containers
 * @component list-item
 * @variations collab-ui-react
 */

var ListItemHeader =
/*#__PURE__*/
function (_React$PureComponent) {
  function ListItemHeader() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$PureComponent.call.apply(_React$PureComponent, [this].concat(args)) || this, _this.state = {
      id: _.uniqueId(_this.props.id && _this.props.id + "-" || 'cui-space-list-item__header-')
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = ListItemHeader.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        className = _this$props.className,
        children = _this$props.children,
        header = _this$props.header,
        props = _objectWithoutProperties(_this$props, ["className", "children", "header"]);

    var id = this.state.id;
    var staticChildren = [React.createElement(ListItemSection, {
      key: "child-0",
      position: "center"
    }, React.createElement("div", {
      className: 'cui-list-item__header'
    }, header)), React.createElement(ListItemSection, {
      key: "child-1",
      position: "right"
    }, children)];
    return React.createElement(ListItem, _extends({
      className: 'cui-list-item-header' + ("" + (className && " " + className || '')),
      id: id,
      tabIndex: -1,
      onClick: function onClick() {
        return false;
      },
      onKeyDown: function onKeyDown() {
        return false;
      },
      focusable: false
    }, props), staticChildren);
  };

  _inheritsLoose(ListItemHeader, _React$PureComponent);

  return ListItemHeader;
}(React.PureComponent);

ListItemHeader.displayName = 'ListItemHeader';
export { ListItemHeader as default };
ListItemHeader.defaultProps = {
  className: '',
  children: null,
  id: '',
  isReadOnly: true
};
ListItemHeader.propTypes = {
  /** HTML Class for associated input */
  className: PropTypes.string,

  /** ListItemHeader Children */
  children: PropTypes.node,

  /** ListItem header */
  header: PropTypes.string.isRequired,

  /** HTML ID for associated input */
  id: PropTypes.string,

  /** ListItemHeader Bool */
  isReadOnly: PropTypes.bool
};
/**
* @name List Item Header
*
* @category containers
* @component list-item
* @section header
*
* @js
*
import { List, ListItemHeader } from '@collab-ui/react';
import { NavLink } from 'react-router-dom';

export default class SpaceListExamples extends React.PureComponent {

  render() {
    const anchorNode = <NavLink to='/containers/list-item'>More</NavLink>;
    return(
      <div className="medium-4 columns">
        <List>
          <ListItemHeader header='Testing' children={anchorNode} />
        </List>
        <List className='cui--dark' style={{backgroundColor: 'rgba(40,40,40,0.72)'}}>
          <ListItemHeader header='Testing' children={anchorNode}/>
        </List>
      </div>
    );
  }
}
**/

==> react-7.5.0.tgz: package/es/ListItemHeader/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { ListItem, ListItemSection } from "./..";
import _ from 'lodash';
/**
 * @category containers
 * @component list-item
 * @variations collab-ui-react
 */

var ListItemHeader =
/*#__PURE__*/
function (_React$PureComponent) {
  _inheritsLoose(ListItemHeader, _React$PureComponent);

  function ListItemHeader() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$PureComponent.call.apply(_React$PureComponent, [this].concat(args)) || this, _this.state = {
      id: _.uniqueId(_this.props.id && _this.props.id + "-" || 'cui-space-list-item__header-')
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = ListItemHeader.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        className = _this$props.className,
        children = _this$props.children,
        header = _this$props.header,
        type = _this$props.type,
        props = _objectWithoutProperties(_this$props, ["className", "children", "header", "type"]);

    var id = this.state.id;
    var staticChildren = [React.createElement(ListItemSection, {
      key: "child-0",
      position: "center"
    }, React.createElement("div", {
      className: 'cui-list-item__header'
    }, header)), React.createElement(ListItemSection, {
      key: "child-1",
      position: "right"
    }, children)];
    return React.createElement(ListItem, _extends({
      className: 'cui-list-item-header' + ("" + (type && " cui-list-item-header--" + type || '')) + ("" + (className && " " + className || '')),
      id: id,
      tabIndex: -1,
      onClick: function onClick() {
        return false;
      },
      onKeyDown: function onKeyDown() {
        return false;
      },
      focusable: false
    }, props), staticChildren);
  };

  return ListItemHeader;
}(React.PureComponent);

ListItemHeader.displayName = 'ListItemHeader';
export { ListItemHeader as default };
ListItemHeader.defaultProps = {
  className: '',
  children: null,
  id: '',
  isReadOnly: true,
  type: ''
};
ListItemHeader.propTypes = {
  /** HTML Class for associated input */
  className: PropTypes.string,

  /** ListItemHeader Children */
  children: PropTypes.node,

  /** ListItem header */
  header: PropTypes.string.isRequired,

  /** HTML ID for associated input */
  id: PropTypes.string,

  /** ListItemHeader Bool */
  isReadOnly: PropTypes.bool,

  /** ListItemHeader type variation */
  type: PropTypes.oneOf(['', 'space'])
};
/**
* @name List Item Header
*
* @category containers
* @component list-item
* @section header
*
* @js
*
import { List, ListItemHeader } from '@collab-ui/react';
import { NavLink } from 'react-router-dom';

export default class SpaceListExamples extends React.PureComponent {

  render() {
    const anchorNode = <NavLink to='/containers/list-item'>More</NavLink>;
    return(
      <div className="medium-4 columns">
        <List>
          <ListItemHeader header='Testing' children={anchorNode} />
        </List>
        <List className='cui--dark' style={{backgroundColor: 'rgba(40,40,40,0.72)'}}>
          <ListItemHeader header='Testing' children={anchorNode}/>
        </List>
      </div>
    );
  }
}
**/
